<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( version_compare(WP_REALESTATE_PLUGIN_VERSION, '1.6.2', '>=') ) {
    $r = [
        'orderby'         => 'name',
        'order'           => 'ASC',
        'show_count'      => 0,
        'hide_empty'      => 1,
        'parent'          => '',
        'child_of'        => 0,
        'exclude'         => '',
        'selected'        => $selected,
        'hierarchical'    => 1,
        'name'            => $name,
        'depth'           => 0,
        'taxonomy'        => $field['taxonomy'],
        'value'           => 'id',
        'multiple'        => true,
    ];

    $r['lang'] = apply_filters( 'wp-realestate-current-lang', null );

    $categories_hash = 'wre_cats_' . md5( wp_json_encode( $r ) . WP_RealEstate_Cache_Helper::get_transient_version('wre_get_' . $r['taxonomy']) );
    $categories      = get_transient( $categories_hash );

    if ( empty( $categories ) ) {
        $cat_args = [
            'taxonomy'     => $r['taxonomy'],
            'orderby'      => $r['orderby'],
            'order'        => $r['order'],
            'hide_empty'   => $r['hide_empty'],
            'parent'       => $r['parent'],
            'child_of'     => $r['child_of'],
            'exclude'      => $r['exclude'],
            'hierarchical' => $r['hierarchical'],
        ];

        $categories = get_terms( $cat_args );

        set_transient( $categories_hash, $categories, DAY_IN_SECONDS * 7 );
    }

    $output = '';
    if ( ! empty( $categories ) ) {
        include_once WP_REALESTATE_PLUGIN_DIR . '/includes/walkers/class-category-select-walker.php';

        $walker = new WP_RealEstate_Category_Select_Walker();

        if ( $r['hierarchical'] ) {
            $depth = $r['depth'];  // Walk the full depth.
        } else {
            $depth = -1; // Flat.
        }

        $output .= $walker->walk( $categories, $depth, $r );
    }

    if ( !empty($output) ) {
        $placeholder = !empty($field['placeholder']) ? $field['placeholder'] : $field['name'];
    ?>
        <div class="form-group form-group-<?php echo esc_attr($key); ?> tax-select-field">
            <?php if ( !isset($field['show_title']) || $field['show_title'] ) { ?>
                <label for="<?php echo esc_attr( $args['widget_id'] ); ?>_<?php echo esc_attr($key); ?>" class="heading-label">
                    <?php echo wp_kses_post($field['name']); ?>
                </label>
            <?php } ?>
            <div class="form-group-inner inner select-wrapper">
                <select name="<?php echo esc_attr($name); ?>" class="form-control" id="<?php echo esc_attr( $args['widget_id'] ); ?>_<?php echo esc_attr($key); ?>" <?php if ( !empty($placeholder) ) { ?>
                        data-placeholder="<?php echo esc_attr($placeholder); ?>"
                        <?php } ?>>

                        <option value=""><?php echo esc_attr($placeholder); ?></option>
                        
                    <?php echo $output; ?>
                </select>
            </div>
        </div><!-- /.form-group -->
    <?php }
} else {
    $output = WP_RealEstate_Abstract_Filter::hierarchical_tax_option_tree(0, 0, $name, $key, $field, $selected );

    if ( !empty($output) ) {
        $placeholder = !empty($field['placeholder']) ? $field['placeholder'] : sprintf(esc_html__('Filter by %s', 'homeo'), $field['name']);
    ?>
        <div class="form-group form-group-<?php echo esc_attr($key); ?> tax-select-field">
            <?php if ( !isset($field['show_title']) || $field['show_title'] ) { ?>
                <label for="<?php echo esc_attr( $args['widget_id'] ); ?>_<?php echo esc_attr($key); ?>" class="heading-label">
                    <?php echo wp_kses_post($field['name']); ?>
                </label>
            <?php } ?>
            <div class="form-group-inner inner select-wrapper">
                <?php if ( !empty($field['icon']) ) { ?>
                    <i class="<?php echo esc_attr( $field['icon'] ); ?>"></i>
                <?php } ?>
                <select name="<?php echo esc_attr($name); ?>" class="form-control" id="<?php echo esc_attr( $args['widget_id'] ); ?>_<?php echo esc_attr($key); ?>" data-placeholder="<?php echo esc_attr($placeholder); ?>">
                    <option value=""><?php echo esc_html($placeholder); ?></option>
                    <?php echo trim($output); ?>
                </select>
            </div>
        </div><!-- /.form-group -->
    <?php }
}